@@ -1,4 +1,4 @@
-#!/tmp/bin/perl
+#!/usr/app/bin/perl
 
 # example for the gimp-perl-server (also called Net-Server)
 
@@ -29,7 +29,7 @@ sub net {
 #  Gimp::Net::server_quit;  # kill the gimp-perl-server-extension (ugly name)
 }
 
-exit gimp_main;
+exit main;
 
 
 
