@@ -1,9 +1,9 @@
-#!/tmp/bin/perl
+#!/usr/app/bin/perl
 
 use Gimp;
 use Gimp::Fu;
 
-Gimp::set_trace(TRACE_ALL);
+#Gimp::set_trace(TRACE_ALL);
 
 register "webify",
          "Make an image suitable for the web",
